@@ -39,23 +39,44 @@ func (n Namespace) ColorerFunc() model1.ColorerFunc {
 	}
 }
 
-// Header returns a header rbw.
-func (Namespace) Header(string) model1.Header {
+// Header returns a header row.
+func (n Namespace) Header(_ string) model1.Header {
+	return n.doHeader(n.defaultHeader())
+}
+
+func (Namespace) defaultHeader() model1.Header {
 	return model1.Header{
 		model1.HeaderColumn{Name: "NAME"},
 		model1.HeaderColumn{Name: "STATUS"},
-		model1.HeaderColumn{Name: "LABELS", Wide: true},
-		model1.HeaderColumn{Name: "VALID", Wide: true},
-		model1.HeaderColumn{Name: "AGE", Time: true},
+		model1.HeaderColumn{Name: "LABELS", Attrs: model1.Attrs{Wide: true}},
+		model1.HeaderColumn{Name: "VALID", Attrs: model1.Attrs{Wide: true}},
+		model1.HeaderColumn{Name: "AGE", Attrs: model1.Attrs{Time: true}},
 	}
 }
 
 // Render renders a K8s resource to screen.
-func (n Namespace) Render(o interface{}, _ string, r *model1.Row) error {
+func (n Namespace) Render(o interface{}, ns string, row *model1.Row) error {
 	raw, ok := o.(*unstructured.Unstructured)
 	if !ok {
-		return fmt.Errorf("expected Namespace, but got %T", o)
+		return fmt.Errorf("expected NetworkPolicy, but got %T", o)
 	}
+	if err := n.defaultRow(raw, row); err != nil {
+		return err
+	}
+	if n.specs.isEmpty() {
+		return nil
+	}
+
+	cols, err := n.specs.realize(raw, n.defaultHeader(), row)
+	if err != nil {
+		return err
+	}
+	cols.hydrateRow(row)
+
+	return nil
+}
+
+func (n Namespace) defaultRow(raw *unstructured.Unstructured, r *model1.Row) error {
 	var ns v1.Namespace
 	err := runtime.DefaultUnstructuredConverter.FromUnstructured(raw.Object, &ns)
 	if err != nil {
