@@ -12,6 +12,7 @@ import (
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/ui"
+	"github.com/derailed/k9s/internal/view/cmd"
 	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
 	"github.com/sahilm/fuzzy"
@@ -58,6 +59,7 @@ func NewDetails(app *App, title, subject, contentType string, searchable bool) *
 	return &d
 }
 
+func (d *Details) SetCommand(*cmd.Interpreter)      {}
 func (d *Details) SetFilter(string)                 {}
 func (d *Details) SetLabelFilter(map[string]string) {}
 
@@ -168,6 +170,7 @@ func (d *Details) StylesChanged(s *config.Styles) {
 // Update updates the view content.
 func (d *Details) Update(buff string) *Details {
 	d.model.SetText(buff)
+
 	return d
 }
 
